pyOpenSSL - necessario para a biblioteca Requests.

# Historico de versoes:

1.2.0: Criacao e adicao de resource para cancelamento de recorrencia.

1.1.9: Foi retirado o caracter com acento (ascii invalido) deste documento.

1.1.8: #BUG FIX

1.1.7: #BUG FIX

1.1.6: Adicao do certificado "pyOpenSSL" para a biblioteca Requests

1.1.5: Adicionado um resource para o retorno da recorrencia.

1.1.4: Atualizacao da biblioteca Requests

1.1.3: #BUG FIX

1.1.2: Adicao de desconto, multa e juros para geracao de boletos.
